@@ -8,7 +8,7 @@ def jnb_clean(
     is_debug: bool = typer.Option(False, "--v", help="only show info not run"),
 ):
     """
-    clean notebooks folder, only git clean data, but keep src for reproduce
+    clean notebooks folder, only git clean data, but keep src for reproduce. skip nb file startswith skip
     """
     try:
         import jammy.io as jio
@@ -24,7 +24,7 @@ def jnb_clean(
             continue
         names = in_nb_file.split("/")
         nb_file_name = names[-1].split(".")[0]
-        if nb_file_name.startswith("_clean_"):
+        if nb_file_name.startswith("_clean_") or nb_file_name.startswith("skip"):
             continue
         out_nb_file = "/".join(names[:-1]) + f"/_clean_{nb_file_name}.ipynb"
         jio.copy(in_nb_file, out_nb_file)
