@@ -125,9 +125,10 @@ def ls_print_jobs(parsed_jobs, selected_status=None):
             )
             print(df.to_string(index=False))
 
-def collect_job(is_dir, key):
+def collect_job(is_dir, key, ace=2):
+    ace = f"nv-us-west-{ace}"
     team = 'deep-imagination' if is_dir else 'lpr-imagine'
-    stdout, stderr = run_simple_command(f'ngc batch list --format_type json --team {team}')
+    stdout, stderr = run_simple_command(f'ngc batch list --format_type json --team {team} --ace {ace}')
     if stderr:
         print('ngc batch list error')
         print(stderr)
@@ -142,18 +143,20 @@ def collect_job(is_dir, key):
 def _ngc_list(
     is_dir : bool = typer.Option(False, "-t/-T", help="defualt use lpr-imagine, otherwise use deep-imagination"),
     key : str = typer.Option('ml', help='filter key, only show jobs whose names contain the key'),
+    ace : int = typer.Option(2, help='ace number, default 2'),
     status : str = typer.Option('none', help='filter status, only show jobs whose status is the status'),
 ):
     status = None if status.lower() == 'none' else status
-    parsed_jobs = collect_job(is_dir, key)
+    parsed_jobs = collect_job(is_dir, key, ace)
     ls_print_jobs(parsed_jobs, status)
 
 def _ngc_result(
     is_dir : bool = typer.Option(False, "-t/-T", help="defualt use lpr-imagine, otherwise use deep-imagination"),
     key : str = typer.Option('ml', help='filter key, only show jobs whose names contain the key'),
+    ace : int = typer.Option(2, help='ace number, default 2'),
     is_fzf : bool = typer.Option(False, "-i/-I", help="use iteractive fzf to select job, default false -> use latest job"),
 ):
-    parsed_jobs = collect_job(is_dir, key)
+    parsed_jobs = collect_job(is_dir, key, ace)
     # parsed_jobs = {k: v if k in [] for k, v in parsed_jobs.items()}
     if 'QUEUED' in parsed_jobs:
         del parsed_jobs['QUEUED']
@@ -197,9 +200,10 @@ def _ngc_result(
 def _ngc_bash(
     is_dir : bool = typer.Option(False, "-t/-T", help="defualt use lpr-imagine, otherwise use deep-imagination"),
     key : str = typer.Option('ml', help='filter key, only show jobs whose names contain the key'),
+    ace : int = typer.Option(2, help='ace number, default 2'),
     is_fzf : bool = typer.Option(False, "-i/-I", help="use iteractive fzf to select job, default false -> use latest job"),
 ):
-    parsed_jobs = collect_job(is_dir, key)
+    parsed_jobs = collect_job(is_dir, key, ace)
     all_jobs = []
     for k, v in parsed_jobs.items():
         if k in ['QUEUED', 'STARTING', 'RUNNING']:
@@ -238,10 +242,11 @@ def _ngc_bash(
 def _ngc_kill(
     is_dir : bool = typer.Option(False, "-t/-T", help="defualt use lpr-imagine, otherwise use deep-imagination"),
     key : str = typer.Option('ml', help='filter key, only show jobs whose names contain the key'),
+    ace : int = typer.Option(2, help='ace number, default 2'),
     is_fzf : bool = typer.Option(True, "-i/-I", help="use iteractive fzf to select job, default true. otherwise delete all jobs"),
     confirm : bool = typer.Option(False, "-c/-C", help="confirm to kill job, default false -> only print"),
 ):
-    parsed_jobs = collect_job(is_dir, key)
+    parsed_jobs = collect_job(is_dir, key, ace)
     all_jobs = []
     for k, v in parsed_jobs.items():
         if k in ['QUEUED', 'STARTING', 'RUNNING']:
